==> jc-1.4.0.tar.gz: gnu/classpath/RawData64.h <==
// public final class gnu.classpath.RawData64

// class file dependencies
// @dep_class 62c7aaff42351a78 gnu_classpath_RawData
// @dep_class 778d1cc48cbca526 gnu_classpath_RawData64
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_classpath_RawData

#include "gnu/classpath/RawData.h"

#ifndef _JC_gnu_classpath_RawData64_H_
#define _JC_gnu_classpath_RawData64_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_classpath_RawData64$sub_refs	_jc_gnu_classpath_RawData64$sub_refs;
typedef struct _jc_gnu_classpath_RawData64$sub_nonrefs	_jc_gnu_classpath_RawData64$sub_nonrefs;
typedef struct _jc_gnu_classpath_RawData64$refs	_jc_gnu_classpath_RawData64$refs;
typedef struct _jc_gnu_classpath_RawData64$nonrefs	_jc_gnu_classpath_RawData64$nonrefs;
typedef struct _jc_gnu_classpath_RawData64$object	_jc_gnu_classpath_RawData64$object;

typedef const struct _jc_gnu_classpath_RawData64$vmethods	_jc_gnu_classpath_RawData64$vmethods;
typedef const struct _jc_gnu_classpath_RawData64$vtable	_jc_gnu_classpath_RawData64$vtable;
typedef const struct _jc_gnu_classpath_RawData64$vtype	_jc_gnu_classpath_RawData64$vtype;

// Constructors
extern void _jc_gnu_classpath_RawData64$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_gnu_classpath_RawData64$object *, jlong);

// Virtual methods structure
struct _jc_gnu_classpath_RawData64$vmethods {
};

// Vtable
struct _jc_gnu_classpath_RawData64$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_RawData$vmethods	gnu_classpath_RawData;
	_jc_gnu_classpath_RawData64$vmethods	gnu_classpath_RawData64;
};

// Vtype
struct _jc_gnu_classpath_RawData64$vtype {
	_jc_type			type;
	_jc_gnu_classpath_RawData64$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_RawData64$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_RawData64$refs {
    _jc_gnu_classpath_RawData64$sub_refs	gnu_classpath_RawData64;
    _jc_gnu_classpath_RawData$sub_refs	gnu_classpath_RawData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_RawData64$sub_nonrefs {
	jlong	data;
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_RawData64$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_RawData$sub_nonrefs	gnu_classpath_RawData;
    _jc_gnu_classpath_RawData64$sub_nonrefs	gnu_classpath_RawData64;
};

// Object instance structure
struct _jc_gnu_classpath_RawData64$object {
	_jc_gnu_classpath_RawData64$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_RawData64$vtype	*vtype;
	_jc_gnu_classpath_RawData64$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_RawData64$vtype _jc_gnu_classpath_RawData64$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_RawData64, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_RawData64$class_object;

#endif	/* _JC_gnu_classpath_RawData64_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/RawData64.h <==
// public final class gnu.classpath.RawData64

// class file dependencies
// @dep_class 62c7aaff42351a78 gnu_classpath_RawData
// @dep_class 778d1cc48cbca526 gnu_classpath_RawData64
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_classpath_RawData

#include "gnu/classpath/RawData.h"

#ifndef _JC_gnu_classpath_RawData64_H_
#define _JC_gnu_classpath_RawData64_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_classpath_RawData64$sub_refs	_jc_gnu_classpath_RawData64$sub_refs;
typedef struct _jc_gnu_classpath_RawData64$sub_nonrefs	_jc_gnu_classpath_RawData64$sub_nonrefs;
typedef struct _jc_gnu_classpath_RawData64$refs	_jc_gnu_classpath_RawData64$refs;
typedef struct _jc_gnu_classpath_RawData64$nonrefs	_jc_gnu_classpath_RawData64$nonrefs;
typedef struct _jc_gnu_classpath_RawData64$object	_jc_gnu_classpath_RawData64$object;

typedef const struct _jc_gnu_classpath_RawData64$vmethods	_jc_gnu_classpath_RawData64$vmethods;
typedef const struct _jc_gnu_classpath_RawData64$vtable	_jc_gnu_classpath_RawData64$vtable;
typedef const struct _jc_gnu_classpath_RawData64$vtype	_jc_gnu_classpath_RawData64$vtype;

// Constructors
extern void _jc_gnu_classpath_RawData64$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_gnu_classpath_RawData64$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_classpath_RawData64$vmethods {
};

// Vtable
struct _jc_gnu_classpath_RawData64$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_RawData$vmethods	gnu_classpath_RawData;
	_jc_gnu_classpath_RawData64$vmethods	gnu_classpath_RawData64;
};

// Vtype
struct _jc_gnu_classpath_RawData64$vtype {
	_jc_type			type;
	_jc_gnu_classpath_RawData64$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_RawData64$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_RawData64$refs {
    _jc_gnu_classpath_RawData64$sub_refs	gnu_classpath_RawData64;
    _jc_gnu_classpath_RawData$sub_refs	gnu_classpath_RawData;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_RawData64$sub_nonrefs {
	jlong	data;
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_RawData64$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_RawData$sub_nonrefs	gnu_classpath_RawData;
    _jc_gnu_classpath_RawData64$sub_nonrefs	gnu_classpath_RawData64;
};

// Object instance structure
struct _jc_gnu_classpath_RawData64$object {
	_jc_gnu_classpath_RawData64$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_RawData64$vtype	*vtype;
	_jc_gnu_classpath_RawData64$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_RawData64$vtype _jc_gnu_classpath_RawData64$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_RawData64, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_RawData64$class_object;

#endif	/* _JC_gnu_classpath_RawData64_H_ */
